@@ -52,3 +52,9 @@ P::V       46729/s        --      -49%      -56%      -70%
 S::A       91743/s       96%        --      -13%      -40%
 SM::A     105263/s      125%       15%        --      -32%
 S::A_fast 153846/s      229%       68%       46%        --
+
+             Rate      P::V      S::A     SM::A S::A_fast
+P::V      24691/s        --      -55%      -60%      -71%
+S::A      54945/s      123%        --      -12%      -35%
+SM::A     62500/s      153%       14%        --      -26%
+S::A_fast 84746/s      243%       54%       36%        --
